---
title: Pyqrlew API Documentation
---

# Pyqrlew API Documentation

# Dataset
- {doc}`api`
- {doc}`compilation_rules`

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`

# Bibliography

```{toctree}
---
maxdepth: 2
hidden:
titlesonly:
---
api
io
```